GraphEditor

Struct GraphEditor 

pub struct GraphEditor<'a, G: GraphAdapter> { /* private fields */ }
A graph editor to render and manipulate a graph throw the GraphAdapter trait.

Implementations

Source

impl<'a, G: GraphAdapter> GraphEditor<'a, G>

pub fn new(graph: G, id_source: impl Hash) -> Self

Creates a new GraphEditor.

Source

impl<'a, G: GraphAdapter> GraphEditor<'a, G>

pub fn look_at(self, pos: Pos) -> Self

Move the viewport to make pos on the center of the viewport.

pub fn grid_stroke(self, stroke: impl Into<Stroke>) -> Self

The stroke used to render the background grid.

Use Stroke::NONE to disable the grid.

pub fn view_aspect(self, view_aspect: f32) -> Self

width / height ratio of the editor region.

By default no fixed aspect ratio is set (and width/height will fill the ui it is in).

pub fn width(self, width: f32) -> Self

Width of the editor. By default it will fill the ui it is in.

If you set Self::view_aspect, the width can be calculated from the height.

pub fn height(self, height: f32) -> Self

Height of the editor. By default it will fill the ui it is in.

If you set Self::view_aspect, the height can be calculated from the width.

pub fn connection_renderer( self, connection_renderer: impl Into<ConnectionRenderer>, ) -> Self

The ConnectionRenderer used to render the connections between sockets.

It can be one of the renderers defined in connection or a CustomConnectionRenderer.

pub fn context_menu( self, add_contents: impl FnMut(&mut Ui, MenuContext<'_, G>) + 'a, ) -> Self

Defines a callback used to render the context menu of the editor.

See also Response::context_menu.

pub fn node_context_menu( self, add_contents: impl FnMut(&mut Ui, NodeMenuContext<'_, G>) + 'a, ) -> Self

Defines a callback used to render the context menu of a node.

See also Response::context_menu.

pub fn socket_context_menu( self, add_contents: impl FnMut(&mut Ui, SocketMenuContext<'_, G>) + 'a, ) -> Self

Defines a callback used to render the context menu of a sockets.

See also Response::context_menu.

Source

impl<'a, G: GraphAdapter> GraphEditor<'a, G>

pub fn show(self, ui: &mut Ui) -> GraphOutput

Show the graph editor.